@@ -3,7 +3,7 @@ package DateTime::Infinite;
 use strict;
 use warnings;
 
-our $VERSION = '1.22';
+our $VERSION = '1.29';
 
 use DateTime;
 use DateTime::TimeZone;
@@ -26,8 +26,40 @@ sub _seconds_as_components {
     return ( $_[1] ) x 3;
 }
 
+sub ymd {
+    return $_[0]->iso8601;
+}
+
+sub mdy {
+    return $_[0]->iso8601;
+}
+
+sub dmy {
+    return $_[0]->iso8601;
+}
+
+sub hms {
+    return $_[0]->iso8601;
+}
+
+sub hour_12 {
+    return $_[0]->_infinity_string;
+}
+
+sub hour_12_0 {
+    return $_[0]->_infinity_string;
+}
+
+sub iso8601 {
+    return $_[0]->_infinity_string;
+}
+
 sub _stringify {
-    $_[0]->{utc_rd_days} == DateTime::INFINITY
+    return $_[0]->_infinity_string;
+}
+
+sub _infinity_string {
+    return $_[0]->{utc_rd_days} == DateTime::INFINITY
         ? DateTime::INFINITY . ''
         : DateTime::NEG_INFINITY . '';
 }
@@ -166,13 +198,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DateTime::Infinite - Infinite past and future DateTime objects
 
 =head1 VERSION
 
-version 1.22
+version 1.29
 
 =head1 SYNOPSIS
 
@@ -187,23 +221,19 @@ C<DateTime::Infinite::Future> and C<DateTime::Infinite::Past>.
 The objects are in the "floating" timezone, and this cannot be
 changed.
 
-=head1 BUGS
-
-There seem to be lots of problems when dealing with infinite numbers
-on Win32. This may be a problem with this code, Perl, or Win32's IEEE
-math implementation. Either way, the module may not be well-behaved
-on Win32 operating systems.
-
 =head1 METHODS
 
 The only constructor for these two classes is the C<new()> method, as
 shown in the L<SYNOPSIS|/SYNOPSIS>. This method takes no parameters.
 
 All "get" methods in this module simply return infinity, positive or
-negative. If the method is expected to return a string, it return the
+negative. If the method is expected to return a string, it returns the
 string representation of positive or negative infinity used by your
 system. For example, on my system calling C<year()> returns a number
-which when printed appears either "inf" or "-inf".
+which when printed appears either "Inf" or "-Inf".
+
+This also applies to methods that are compound stringifications, which return
+the same strings even for things like C<ymd()> or C<iso8601()>
 
 The object is not mutable, so the C<set()>, C<set_time_zone()>, and
 C<truncate()> methods are all do-nothing methods that simply return
@@ -218,11 +248,26 @@ datetime@perl.org mailing list
 
 http://datetime.perl.org/
 
+=head1 BUGS
+
+There seem to be lots of problems when dealing with infinite numbers
+on Win32. This may be a problem with this code, Perl, or Win32's IEEE
+math implementation. Either way, the module may not be well-behaved
+on Win32 operating systems.
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime>
+(or L<bug-datetime@rt.cpan.org|mailto:bug-datetime@rt.cpan.org>).
+
+There is a mailing list available for users of this distribution,
+L<mailto:datetime@perl.org>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
